==> citation_docket-0.1.2.tar.gz: citation_docket-0.1.2/citation_docket/regexes/constructed_oca.py <==
from typing import Self
from collections.abc import Iterator
from .models import Constructor, DocketCategory, DocketReportCitation
from .models.misc import NUMBER_KEYWORD

separator = r"[\.\s]*"
digit = r"(\d{2}|P)[\d-]*"  # e.g. 323-23, 343-34

end_digit = r"""
    (\d{2,})| # AM OCA IPI No. P-07-2403, Feb. 06, 2008; see also OCA I.P.I. No. 17-4757
    RTJ| # AM OCA IPI No. 11-3800-RTJ, Jun. 19, 2017
    MTJ| # AM OCA IPI No. 04-1606-MTJ, Sep. 19, 2012
    P| # AM OCA IPI No. 09-3138-P, Oct. 22, 2013
    SB-J| # AM OCA IPI No. 10-25-SB-J, Jan. 15, 2013
    CA-J| # AM OCA IPI No. 11-184-CA-J, Jan. 31, 2012
    METC # AM OCA IPI NO. 06-11-392-METC, Jan. 15, 2007
"""

full_digit = rf"""
    {digit}
    ({end_digit})
"""

oca_key = rf"""
    (
        (
            a
            {separator}
            m
            {separator}
        )?
        (
            (OCA)|(O{separator}C{separator}A{separator})
        )
        \s*
        (
            (IPI)|(I{separator}P{separator}I{separator})
        )
        \s*
        {NUMBER_KEYWORD}
    )
"""

required = rf"""
    (?P<oca_init>
        {oca_key}
    )
    (?P<oca_middle>
        {full_digit}
    )
    (?:
        {separator}
    )?
"""


oca_phrases = rf"""
    (?P<oca_phrase>
        {required}
        [\,\s]*
    )
"""

constructed_oca = Constructor(
    label=DocketCategory.OCA.value,
    short_category=DocketCategory.OCA.name,
    group_name="oca_phrase",
    init_name="oca_init",
    docket_regex=oca_phrases,
    key_regex=oca_key,
    num_regex=NUMBER_KEYWORD,
)




class CitationOCA(DocketReportCitation):
    ...

    @classmethod
    def search(cls, text: str) -> Iterator[Self]:
        """Get all dockets matching the `OCA` docket pattern, inclusive of their optional Report object.

        Examples:
            >>> text = "AM OCA IPI No. P-07-2403, Feb. 06, 2008"
            >>> next(CitationOCA.search(text))
            CitationOCA(publisher=None, volume=None, page=None, volpubpage=None, report_date=None, context='AM OCA IPI No. P-07-2403', short_category='OCA', category='Office of the Court Administrator', ids='P-07-2403', docket_date=datetime.date(2008, 2, 6))

        Args:
            text (str): Text to look for citation objects

        Yields:
            Iterator[Self]: Combination of Docket and Report pydantic model.
        """  # noqa E501
        for result in constructed_oca.detect(text):
            yield cls(**result)

==> citation_docket-0.1.5.tar.gz: citation_docket-0.1.5/citation_docket/regexes/constructed_oca.py <==
from collections.abc import Iterator
from typing import Self

from .models import Constructor, DocketCategory, DocketReportCitation
from .models.misc import NUMBER_KEYWORD

separator = r"[\.\s]*"
digit = r"(\d{2}|P)[\d-]*"  # e.g. 323-23, 343-34

end_digit = r"""
    (\d{2,})| # AM OCA IPI No. P-07-2403, Feb. 06, 2008; see also OCA I.P.I. No. 17-4757
    RTJ| # AM OCA IPI No. 11-3800-RTJ, Jun. 19, 2017
    MTJ| # AM OCA IPI No. 04-1606-MTJ, Sep. 19, 2012
    P| # AM OCA IPI No. 09-3138-P, Oct. 22, 2013
    SB-J| # AM OCA IPI No. 10-25-SB-J, Jan. 15, 2013
    CA-J| # AM OCA IPI No. 11-184-CA-J, Jan. 31, 2012
    METC # AM OCA IPI NO. 06-11-392-METC, Jan. 15, 2007
"""

full_digit = rf"""
    {digit}
    ({end_digit})
"""

oca_key = rf"""
    (
        (
            a
            {separator}
            m
            {separator}
        )?
        (
            (OCA)|(O{separator}C{separator}A{separator})
        )
        \s*
        (
            (IPI)|(I{separator}P{separator}I{separator})
        )
        \s*
        {NUMBER_KEYWORD}
    )
"""

required = rf"""
    (?P<oca_init>
        {oca_key}
    )
    (?P<oca_middle>
        {full_digit}
    )
    (?:
        {separator}
    )?
"""


oca_phrases = rf"""
    (?P<oca_phrase>
        {required}
        [\,\s]*
    )
"""

constructed_oca = Constructor(
    label=DocketCategory.OCA.value,
    short_category=DocketCategory.OCA.name,
    group_name="oca_phrase",
    init_name="oca_init",
    docket_regex=oca_phrases,
    key_regex=oca_key,
    num_regex=NUMBER_KEYWORD,
)


class CitationOCA(DocketReportCitation):
    ...

    @classmethod
    def search(cls, text: str) -> Iterator[Self]:
        """Get all dockets matching the `OCA` docket pattern, inclusive of their optional Report object.

        Examples:
            >>> text = "AM OCA IPI No. P-07-2403, Feb. 06, 2008"
            >>> cite = next(CitationOCA.search(text))
            >>> cite.model_dump(exclude_none=True)
            {'context': 'AM OCA IPI No. P-07-2403', 'short_category': <ShortDocketCategory.OCA: 'OCA'>, 'category': <DocketCategory.OCA: 'Office of the Court Administrator'>, 'ids': 'P-07-2403', 'docket_date': datetime.date(2008, 2, 6)}

        Args:
            text (str): Text to look for citation objects

        Yields:
            Iterator[Self]: Combination of Docket and Report pydantic model.
        """  # noqa E501
        for result in constructed_oca.detect(text):
            yield cls(**result)
